@@ -10,7 +10,7 @@ import sys
 import textwrap
 import warnings
 from operator import attrgetter
-from typing import FrozenSet, Match, Tuple
+from typing import Any, FrozenSet, Match, Tuple
 
 import autoflake
 import black
@@ -18,32 +18,16 @@ import isort
 import pyupgrade._main
 from black.mode import TargetVersion
 from black.parsing import lib2to3_parse
+from isort.exceptions import FileSkipComment
 
-from ._codemods import _run_codemods  # type: ignore
-
-
-def _fallback(source: str, **kw: object) -> Tuple[str, object]:
-    return source, None  # pragma: no cover
-
-
-try:
-    from teyit import refactor_until_deterministic as _teyit_refactor
-except ImportError:  # pragma: no cover  # on Python 3.9
-    assert sys.version_info < (3, 9)
-    _teyit_refactor = _fallback
-
-# We can't use a try-except here because com2ann does not declare python_requires,
-# and so it is entirely possible to install it on a Python version that it does
-# not support, and nothing goes wrong until you call the function.  We therefore
-# explicitly check the Python version, while waiting on an upstream fix.
-com2ann = _fallback
-if sys.version_info[:2] >= (3, 8):  # pragma: no cover
-    from com2ann import com2ann  # type: ignore
-
-
-__version__ = "0.8.0"
+__version__ = "0.9.6"
 __all__ = ["shed", "docshed"]
 
+# Conditionally imported in refactor mode to reduce startup latency in the common case
+com2ann: Any = None
+_teyit_refactor: Any = None
+_run_codemods: Any = None
+
 _version_map = {
     k: (int(k.name[2]), int(k.name[3:]))
     for k in TargetVersion
@@ -61,6 +45,10 @@ class ShedSyntaxWarning(SyntaxWarning):
     """Warns that shed has been called on something with invalid syntax."""
 
 
+def _fallback(source: str, **kw: object) -> Tuple[str, object]:
+    return source, None  # pragma: no cover
+
+
 @functools.lru_cache()
 def shed(
     source_code: str,
@@ -82,14 +70,6 @@ def shed(
     if source_code == "":
         return ""
 
-    format_docs = functools.partial(
-        docshed,
-        refactor=refactor,
-        first_party_imports=first_party_imports,
-        min_version=min_version,
-        _location=_location,
-    )
-
     # Use black to autodetect our target versions
     try:
         parsed = lib2to3_parse(
@@ -114,7 +94,13 @@ def shed(
         warnings.warn(w, stacklevel=_location.count(" block in ") + 2)
         # Even if the code itself has invalid syntax, we might be able to
         # regex-match and therefore reformat code embedded in docstrings.
-        return format_docs(source_code)
+        return docshed(
+            source_code,
+            refactor=refactor,
+            first_party_imports=first_party_imports,
+            min_version=min_version,
+            _location=_location,
+        )
     target_versions = set(_version_map) & set(black.detect_target_versions(parsed))
     assert target_versions
     min_version = max(
@@ -123,6 +109,29 @@ def shed(
     )
 
     if refactor:
+        # Here we have a deferred imports section, which is pretty ugly.
+        # It does however have one crucial advantage: several hundred milliseconds
+        # of startup latency in the common case where --refactor was *not* passed.
+        # This is a big deal for interactive use-cases such as pre-commit hooks
+        # or format-on-save in editors (though I prefer Black for the latter).
+        global com2ann
+        global _teyit_refactor
+        global _run_codemods
+        if com2ann is None:
+            from ._codemods import _run_codemods  # type: ignore
+
+            try:
+                from teyit import refactor_until_deterministic as _teyit_refactor
+            except ImportError:  # pragma: no cover  # on Python 3.9
+                assert sys.version_info < (3, 9)
+                _teyit_refactor = _fallback
+            try:
+                from com2ann import com2ann
+            except ImportError:  # pragma: no cover  # on Python 3.8
+                assert sys.version_info < (3, 8)
+                com2ann = _fallback
+            # OK, everything's imported, back to the runtime logic!
+
         # Some tools assume that the file is multi-line, but empty files are valid input.
         source_code += "\n"
         # Use com2ann to comvert type comments to annotations on Python 3.8+
@@ -155,7 +164,6 @@ def shed(
             source_code, settings=pyupgrade._main.Settings(min_version=pyupgrade_min)
         )
     source_code = pyupgrade._main._fix_tokens(source_code, min_version=pyupgrade_min)
-    source_code = pyupgrade._main._fix_py36_plus(source_code, min_version=pyupgrade_min)
 
     if refactor:
         source_code = _run_codemods(source_code, min_version=min_version)
@@ -166,19 +174,28 @@ def shed(
         remove_all_unused_imports=_remove_unused_imports,
     )
 
-    source_code = isort.code(
-        source_code,
-        known_first_party=first_party_imports,
-        known_local_folder={"tests"},
-        profile="black",
-        combine_as_imports=True,
-    )
+    try:
+        source_code = isort.code(
+            source_code,
+            known_first_party=first_party_imports,
+            known_local_folder={"tests"},
+            profile="black",
+            combine_as_imports=True,
+        )
+    except FileSkipComment:
+        pass
 
     if source_code != blackened:
         source_code = black.format_str(source_code, mode=black_mode)
 
     # Then shed.docshed (below) formats any code blocks in documentation
-    source_code = format_docs(source_code)
+    source_code = docshed(
+        source_code,
+        refactor=refactor,
+        first_party_imports=first_party_imports,
+        min_version=min_version,
+        _location=_location,
+    )
     # Remove any extra trailing whitespace
     return source_code.rstrip() + "\n"
 
